@@ -15,6 +15,13 @@ def current_branch():
 
 
 def create_branch(name):
+    """Creates a new branch with <name> based on the current branch
+
+    Returns:
+    str:Returning current git branch name
+
+    """
+
     result = utilities.action("git checkout -b " + name)
     utilities.print_result(result)
     utilities.assert_result(result)
@@ -81,26 +88,26 @@ def merge_request(target, description):
 
 # merge request
 # https://docs.gitlab.com/ee/user/project/merge_requests/merge_when_pipeline_succeeds.html
-# def release_request(version):
+def release_request(version):
 
-#     branch = current_branch()
+    branch = current_branch()
 
-#     request = """\
-#     git push \\
-#     -o merge_request.create \\
-#     -o merge_request.target=develop \\
-#     -o merge_request.merge_when_pipeline_succeeds \\
-#     -o merge_request.remove_source_branch \\
-#     -o merge_request.title=\"Merge request for Release {version}\" \\
-#     -o merge_request.description=\"Release {version}\" \\
-#     origin {branch}
-#   """.format(
-#         version=version, branch=branch
-#     )
+    request = """\
+    git push \\
+    -o merge_request.create \\
+    -o merge_request.target=main \\
+    -o merge_request.merge_when_pipeline_succeeds \\
+    -o merge_request.remove_source_branch \\
+    -o merge_request.title=\"Merge request for Release {version}\" \\
+    -o merge_request.description=\"Release {version}\" \\
+    origin {branch}
+  """.format(
+        version=version, branch=branch
+    )
 
-#     result = utilities.action(request)
-#     utilities.print_result(result)
-#     utilities.assert_result(result)
+    result = utilities.action(request)
+    utilities.print_result(result)
+    utilities.assert_result(result)
 
 
 def get_current_local_tag():
